summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/readmbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/mbox/readmbox.h')
-rw-r--r--kioslaves/mbox/readmbox.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kioslaves/mbox/readmbox.h b/kioslaves/mbox/readmbox.h
index 01b813df7..6fb7394cb 100644
--- a/kioslaves/mbox/readmbox.h
+++ b/kioslaves/mbox/readmbox.h
@@ -53,16 +53,16 @@ public:
/**
* This functions return the current line
* @return The line last read, or QString::null if there wasn't such last line
*/
- QString currentLine() const;
+ TQString currentLine() const;
/**
* This function returns the current id. The id is the first line of an email,
* and is used in filenaming. The id normally starts with "From ".
* @return The current ID, or QString::null if no id was found yet.
*/
- QString currentID() const;
+ TQString currentID() const;
/**
* This function reads the next line. The next line can be read by the currentLine()
@@ -78,7 +78,7 @@ public:
* @param id The id of the message to be found.
* @return true if the message was found, false otherwise.
*/
- bool searchMessage( const QString& id );
+ bool searchMessage( const TQString& id );
/**
* Skips all lines which belongs to the current message. The cursor is on the first line
@@ -117,10 +117,10 @@ private:
void close();
private:
- QFile* m_file;
- QTextStream* m_stream;
- QString* m_current_line;
- QString* m_current_id;
+ TQFile* m_file;
+ TQTextStream* m_stream;
+ TQString* m_current_line;
+ TQString* m_current_id;
bool m_atend;
struct utimbuf* m_prev_time;
@@ -53,16 +53,16 @@ public:
/**
* This functions return the current line
- * @return The line last read, or QString::null if there wasn't such last line
+ * @return The line last read, or TQString::null if there wasn't such last line
*/
@@ -53,16 +53,16 @@ public:
* This function returns the current id. The id is the first line of an email,
* and is used in filenaming. The id normally starts with "From ".
- * @return The current ID, or QString::null if no id was found yet.
+ * @return The current ID, or TQString::null if no id was found yet.
*/